#
# spec file for package python-bashate
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global skip_python2 1
Name:           python-bashate
Version:        2.1.1
Release:        1.9
Summary:        A PEP8 equivalent for bash scripts
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://pypi.org/project/bashate/
Source:         https://files.pythonhosted.org/packages/source/b/bashate/bashate-%{version}.tar.gz
BuildRequires:  %{python_module Babel >= 0.9.6}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testtools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# OpenStack package: stestr is only available for primary python3, only test on this flavor
BuildRequires:  python3-stestr
Requires:       python-Babel >= 0.9.6
Requires:       python-pbr
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%ifpython2
Requires:       python-argparse
%endif
%python_subpackages

%description
A PEP8 equivalent for bash scripts

This program attempts to be an automated style checker for bash scripts
to fill the same part of code review that pep8 does in most OpenStack
projects. It started from humble beginnings in the DevStack project,
and will continue to evolve over time.

- Documentation: http://docs.openstack.org/developer/bashate
- Source: http://git.openstack.org/cgit/openstack-dev/bash8
- Bugs: http://bugs.launchpad.net/bash8

%prep
%setup -q -n bashate-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/bashate
%{python_expand  #
rm -rf %{buildroot}%{$python_sitelib}/bashate/tests
sed -i -e '/^#!\//, 1d' %{buildroot}%{$python_sitelib}/bashate/bashate.py
}
%python_compileall
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
python3 -m stestr.cli run

%post
%python_install_alternative bashate

%postun
%python_uninstall_alternative bashate

%files %{python_files}
%license LICENSE
%doc AUTHORS README.rst ChangeLog
%python_alternative %{_bindir}/bashate
%{python_sitelib}/*

%changelog
* Thu Oct 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2.1.1:
  * No upstream changelog
* Mon Mar  7 2022 pgajdos@suse.com
- python-mock actually not needed for build
* Tue Jan 11 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros dependency
- remove python2 requirement - this is a python 3.x only package
* Mon Nov 29 2021 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * Update IRC network to OFTC
  * Fix doc job
  * Switch testing to Xena testing runtime
  * [CI] Make bashate-devstack job voting and gating
  * setup.cfg: Replace dashes with underscores
  * Add ensure-tox role to test job
  * Changed minversion in tox to 3.18.0
  * remove unicode from code
  * Add Python3 wallaby unit tests
  * Create tox environment to build pdf documentation
  * Remove obsolete files
  * drop mock from lower-constraints and requirements
  * Stop to use the \_\_future\_\_ module
  * Switch to newer openstackdocstheme and reno versions
  * Fix hacking min version to 3.0.1
  * Switch testing to Victoria testing runtime
  * [ussuri][goal] Update contributor documentation
  * Cleanup py27 support
  * Update hacking for Python3
* Wed Jan 27 2021 Benjamin Greiner <code@bnavigator.de>
- Only test the primary python3 flavor, because only python3 has
  stestr (OpenStack package)
* Tue Jun 23 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.0.0:
  * Add Python 3.5 support
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Feb 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.0.0:
  * Add an ability to specify max line length
  * [ussuri][goal] Drop python 2.7 support and testing
  * Convert devstack-bashate to native job
  * Add release notes and contributing in readme
  * Add Python 3 Train unit tests
  * Add --version option
  * Remove pylintrc file
  * Use stestr as a test runner
  * Update sphinx version
  * Update to opendev
  * Dropping the py35 testing
  * OpenDev Migration Patch
  * Replace openstack.org git:// URLs with https://
  * Replace openstack.org git:// URLs with https://
  * Change openstack-dev to openstack-discuss
  * Update min tox version to 2.0
  * fix tox python3 overrides
  * add python 3.6 unit test job
  * switch documentation job to new PTI
  * import zuul job settings from project-config
* Sun May 19 2019 Markos Chandras <mchandras@suse.de>
- Add python-pbr to runtime dependencies since bashate is trying to
  import it at the very beginning.
* Tue Feb 12 2019 Jan Engelhardt <jengelh@inai.de>
- Remove redundant metadata reprisal from description.
* Tue Feb 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Run the fdupes call properly to avoid rpmlint warnings
* Mon Feb 11 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v0.6.0
  * Address new pypi requirements on README.rst
  * Switch to pep8 output format
  * Enable bashate use with pre-commit
  * Allow bashate to be called as a module
  * Add bindep.txt file
  * Stop using slave\_scripts/install-distro-packages.sh
  * Use openstack-tox-py36
  * Convert bashate-python36-fedora-26 to Zuul v3
  * Remove setting of version/release from releasenotes
  * Zuul: add file extension to playbook path
  * Initial zuulv3 job import
  * Update documentation URL for readme file
  * Add a [[ checker
  * Don't mock sysv.args
  * Fix formatting of contributor page
  * Treat sphinx warnings as errors
  * Reorder content to follow new structure
  * Update to openstackdocstheme
  * Update to tox.ini environment list
  * Add py3.5 support in setup.cfg
  * correcting typo in EXAMPLES section -I should be -i
  * docs: fixed CLI args description
  * Update .coveragerc after the removal of openstack directory
  * Changed the home-page link
  * Don't include openstack/common in flake8 exclude list
  * Enable release notes translation
  * Update docs to include all errors
  * Exclude hashbangs check for .bashrc, .bash\_profile, etc
- Add Python 3 support
- Add %%license
- Remove tests from installed package
* Tue Oct 25 2016 dmueller@suse.com
- update to 0.5.1:
  * Add releasenote on python3
  * Handle argument line-up in continuations
  * Cleanup continuation line handling
  * Ignore heredoc contents
  * Replace heredoc fail-to-end detection E012 with "bash -n"
  * Set up locale for bash syntax testing
  * Only warn about tab-indent
  * Add shallow syntax checking
* Fri Nov 20 2015 dmueller@suse.com
- update to 0.3.2:
  * Detect setting locals with subshell commands
  * Change ignore-errors to ignore_errors
  * Move to hacking 0.10
  * add E006: check for lines longer than 79 columns
  * Cleanup variable names TODO
  * Fix broken py3 tests
  * Change non intuitive error message
  * Don't mock argparse
  * Add #! or .sh test at warning level
  * Move messages into a dict
  * Add --warn to turn messages down to warnings
  * Remove pylint from requirements
  * Change test order to avoid incompatibliity
  * Clean-up return statements
  * Workflow documentation is now in infra-manual
  * Put all messages into separate package
  * Removed \b that don't work anyway
* Sat Nov  8 2014 dmueller@suse.com
- update to 0.3.1:
  * Add man page
  * Remove automagic file finder
  * Strip comments before checks
  * Revert "Add E040: $(COMMAND) preferred over `COMMAND`"
  * Check for bash-like "for"
  * Warn against sorting requirements
  * Rename doc environment to docs
  * Add Pylint testenv environment
  * Add a check for $[
  * Add E040: $(COMMAND) preferred over `COMMAND`
  * Treat if and elif equally
  * Add new register_ignores unit tests
  * Clean-up E011 and E020 messages
  * Bump hacking to 0.9.x series
  * Reduce loops and if statements in method discover_files
  * Remove unneeded definitions of Python Source Code Encoding
  * Add a space to the output of the method log_error
  * Fix source location URL in README
  * Fix .gitreview project path
* Tue Oct  7 2014 dmueller@suse.com
- Initial package (0.2.0)
